﻿--[[ Guild Management Tools Data Miner
  -- URL: http://addons.nobilityguild.org/
  -- 
  -- License:
  -- 	This program is free software; you can redistribute it and/or
  -- 	modify it under the terms of the GNU General Public License
  -- 	as published by the Free Software Foundation; either version 2
  -- 	of the License, or (at your option) any later version.
  -- 	This program is distributed in the hope that it will be useful,
  -- 	but WITHOUT ANY WARRANTY; without even the implied warranty of
  -- 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  -- 	GNU General Public License for more details.
  -- 	You should have received a copy of the GNU General Public License
  -- 	along with this program(see GPL.txt); if not, write to the Free Software
  -- 	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
--]]
--
--[[ 1.0     Addon Declarations
  -- 1.1         Localizations using AceLocale-3.0
--]]

--local L = LibStub("AceLocale-3.0"):GetLocale("GuildManagementTools", false)


--~ 1.2         Registering Addons
--[[ 1.2.1           LibDebugLog -   Used to control the diaply of various debug messages; this library is missing some desired features. I will probably write this into the LibGMT library at some point.
  -- 1.2.1.1             Mixin API
  -- 1.2.1.1.1               :Debug( msg [, ...] )
  --                             Sends a debug log message.
  --                             msg is converted to string. If more arguments are provided, they are converted to strings. If msg contains at least one '%', sends msg:format(...), else join all arguments.
  -- 1.2.1.1.2               :ToggleDebugLog( enable )
  --                             Enable debug logging if enable is true.
  -- 1.2.1.1.3               :IsDebugLogEnabled()
  --                             Returns true if debug logs are enabled.
  -- 1.2.1.2             Library API
  --                         These methods have to be called from the library itself, e.g. :
  --                             LibStub('LibLogDebug-1.0'):SetGlobalToggle(false)
  -- 1.2.1.2.1               :Embed(broker)
  --                             Add the embeddable API into the broker and registers the broker.
  -- 1.2.1.2.2               :SetGlobalToggle( enable )
  --                             Forcibly set the log state of all registered brokers.
  --                                 Possible values of enable are:
  --                                     true    -   forcibly enable debug log.
  --                                     false   -   forcibly disable debug log.
  --                                     nil     -   restores each broker state.
  -- 1.2.1.2.3               :GetGlobalToggle()
  --                             Returns the current state of the global toggle.
  -- 1.2.1.2.4               :GetAce3OptionTable( logger[, order] )
  --                             Returns a table to be used as an AceConfig3 option table.
  --                                 function addon:OnInitialize()
  --                                   local options = {
  --                                     name = 'MyAddon',
  --                                     type = 'group',
  --                                     handler = self,
  --                                     args = {
  --                                       enable = {
  --                                         name = 'Enable',
  --                                         type = 'toggle',
  --                                         get = 'IsEnabled',
  --                                         set = 'EnableAddon',
  --                                         order = 100,
  --                                       },
  --                                       debug = LibStub('LibLogDebug-1.0'):GetAce3OptionTable(self, 110),
  --                                       -- put other useful options here
  --                                     }
  --                                   }
  --                                   LibStub("AceConfig-3.0"):RegisterOptionsTable(self.name, options)
  --                                 end
--]]

--[[ 1.2.2           AceEvent
  -- 1.2.2.1             Subscribing to events
  -- 1.2.2.1.1               MyAddon:RegisterEvent("NAME_OF_EVENT", "MyHandlerMethod")
  --                             function MyAddon:NAME_OF_EVENT(eventName, arg1, arg2, arg3)
  --                             -- do some stuff
  --                             end
  -- 
  --                             function MyAddon:NAME_OF_OTHER_EVENT(eventName, ...)
  --                             -- do some more stuff
  --                             end
  -- 1.2.2.1.2               MyAddon:UnregisterEvent("NAME_OF_EVENT")
  -- 1.2.2.2             Sending/receiving inter-addon messages
  --                         AceEvent also provides support for "messages", which are basically like events except instead of being triggered by the WoW client, they're triggered by other addons. This is useful if you have multiple addons which need to talk to each other. Messages are subscribed to very similarly to events (and the alternate options for specifying handlers work for RegisterMessage, too):
  -- 1.2.2.2.1               MyAddon:RegisterMessage("NAME_OF_MESSAGE")
  -- 
  --                             function MyAddon:NAME_OF_MESSAGE()
  --                                 -- handle the message
  --                             end
  -- 1.2.2.2.2               MyAddon:UnregisterMessage("NAME_OF_MESSAGE")
  -- 1.2.2.2.3               Sending messages to other addons is just as simple:
  --                             MyAddon:SendMessage("NAME_OF_MESSAGE")
  --                             MyAddon:SendMessage("NAME_OF_OTHER_MESSAGE", arg1, arg2)
  --                             Note that messages are only for addons running on the same client! If you want to send messages between various players and their addons, you'll want to use AceComm.
  -- --
--]]
--[[ 1.2.3           AceTimer
  --                     This creates a timer, to call the function self:UpdatePartyGUIDs() after 0.5 seconds, but only if a timer to do it doesn't already exist.
  --                     Code:
  --                         if not timers.UpdatePartyGUIDs then
  --                             timers.UpdatePartyGUIDs = self:ScheduleTimer("UpdatePartyGUIDs", 0.5)
  --                         end
  --                     Now this is a one-shot timer, its not a repeating timer. When it fires, the handle no longer becomes valid, you need to nil out the invalid timer to it.
  --                     Code:
  --                     function Omen:UpdatePartyGUIDs()
  --                         timers.UpdatePartyGUIDs = nil
  --                         -- blah blah rest of code
  --                     end
  --                     Now, the function UpdatePartyGUIDs() can be called from many places, not just from a timer. So we cancel the timer if it exists (that is we cancel the timer if some other code calls it ahead of the timer), and also have it not error on a invalid timer handle by sending it "true" in the second argument.
  --                     Code:
  --                     function Omen:UpdatePartyGUIDs()
  --                         if timers.UpdatePartyGUIDs then
  --                             self:CancelTimer(timers.UpdatePartyGUIDs, true)
  --                             timers.UpdatePartyGUIDs = nil
  --                         end
  --                         -- blah blah rest of code
  --                     end
  -- --
--]]
--[[ 1.2.4           AceBucket
  --                     Not Currently Used - Marked for deletion
--]]

